@@ -138,23 +138,7 @@ void SettingsController::showSettingsDialog()
 
     connect(dialog, &KConfigDialog::settingsChanged, this, &SettingsController::generalSettingsChanged);
 
-// Spellcheck
-#if 0
-    w = new Sonnet::ConfigWidget(Settings::self()->config(), dialog);
-    w->setParent(this);
-    dialog->addPage(w, i18nc("@title:tab", "Spellcheck"), "spellcheck_setting");
-    connect(dialog, SIGNAL(okClicked()), w, SLOT(save()));
-    connect(dialog, SIGNAL(applyClicked()), w, SLOT(save()));
-    connect(dialog, SIGNAL(defaultClicked()), w, SLOT(slotDefault()));
-#endif
-
-    // connect(dialog,SIGNAL(settingsChanged(const QString&)),m_view, SLOT(settingsChanged()));
-
     dialog->show();
-    //    dialog->addPage(new General(0, "General"), i18n("General") );
-    //    dialog->addPage(new Appearance(0, "Style"), i18n("Appearance") );
-    //    connect(dialog, SIGNAL(settingsChanged(const QString&)), mainWidget, SLOT(loadSettings()));
-    //    connect(dialog, SIGNAL(settingsChanged(const QString&)), this, SLOT(loadSettings()));
 }
 
 bool SettingsController::ensureProjectIsLoaded()
@@ -179,13 +163,7 @@ bool SettingsController::ensureProjectIsLoaded()
 QString SettingsController::projectOpen(QString path, bool doOpen)
 {
     if (path.isEmpty()) {
-        // Project::instance()->model()->weaver()->suspend();
-        // KDE5PORT mutex if needed
-        path = QFileDialog::getOpenFileName(m_mainWindowPtr,
-                                            QString(),
-                                            QDir::homePath() /*_catalog->url().directory()*/,
-                                            i18n("Lokalize translation project (*.lokalize)") /*"text/x-lokalize-project"*/);
-        // Project::instance()->model()->weaver()->resume();
+        path = QFileDialog::getOpenFileName(m_mainWindowPtr, QString(), QDir::homePath(), i18n("Lokalize translation project (*.lokalize)"));
     }
 
     if (!path.isEmpty() && doOpen)
@@ -196,16 +174,13 @@ QString SettingsController::projectOpen(QString path, bool doOpen)
 
 bool SettingsController::projectCreate()
 {
-    // Project::instance()->model()->weaver()->suspend();
-    // KDE5PORT mutex if needed
     QString desirablePath = Project::instance()->desirablePath();
     if (desirablePath.isEmpty())
         desirablePath = QDir::homePath() + QStringLiteral("/index.lokalize");
     QString path = QFileDialog::getSaveFileName(m_mainWindowPtr,
                                                 i18nc("@window:title", "Select folder with Gettext .po files to translate"),
                                                 desirablePath,
-                                                i18n("Lokalize translation project (*.lokalize)") /*"text/x-lokalize-project"*/);
-    // Project::instance()->model()->weaver()->resume();
+                                                i18n("Lokalize translation project (*.lokalize)"));
     if (path.isEmpty())
         return false;
 
@@ -216,8 +191,6 @@ bool SettingsController::projectCreate()
         projectId = projectFolder.dirName() + QLatin1Char('-') + projectId;
     ;
     Project::instance()->load(path, QString(), projectId);
-    // Project::instance()->setDefaults(); //NOTE will this be an obstacle?
-    // Project::instance()->setProjectID();
 
     QTimer::singleShot(500, this, &SettingsController::projectConfigure);
     return true;
@@ -311,7 +284,6 @@ void SettingsController::reflectProjectConfigChange()
 
 void SettingsController::reflectRelativePathsHack()
 {
-    // m_scriptsRelPrefWidget->clear();
     QStringList actionz(m_scriptsPrefWidget->items());
     QString projectDir(Project::instance()->projectDir());
     int i = actionz.size();
