@@ -12,7 +12,6 @@
 #include "projecttab.h"
 #include "catalog.h"
 #include "lokalize_debug.h"
-#include "prefs.h"
 #include "prefs_lokalize.h"
 #include "project.h"
 #include "projectwidget.h"
@@ -44,69 +43,14 @@
 #include <QVBoxLayout>
 
 ProjectTab::ProjectTab(QWidget *parent)
-    : LokalizeSubwindowBase2(parent)
+    : LokalizeTabPageBase(parent)
     , m_browser(new ProjectWidget(this))
     , m_filterEdit(new QLineEdit(this))
 
 {
-    setWindowTitle(i18nc("@title:window", "Project Overview")); // setCaption(i18nc("@title:window","Project"),false);
-    // BEGIN setup welcome widget
-    QWidget *welcomeWidget = new QWidget(this);
-    QVBoxLayout *wl = new QVBoxLayout(welcomeWidget);
-    QLabel *about = new QLabel(i18n("<html>" // copied from kaboutkdedialog_p.cpp
-                                    "You do not have to be a software developer to be a member of the "
-                                    "KDE team. You can join the language teams that translate "
-                                    "program interfaces. You can provide graphics, themes, sounds, and "
-                                    "improved documentation. You decide!"
-                                    "<br /><br />"
-                                    "Visit "
-                                    "<a href=\"%1\">%1</a> "
-                                    "for information on some projects in which you can participate."
-                                    "<br /><br />"
-                                    "If you need more information or documentation, then a visit to "
-                                    "<a href=\"%2\">%2</a> "
-                                    "will provide you with what you need.</html>",
-                                    QLatin1String("https://community.kde.org/Get_Involved"),
-                                    QLatin1String("https://techbase.kde.org/")),
-                               welcomeWidget);
-    about->setAlignment(Qt::AlignCenter);
-    about->setWordWrap(true);
-    about->setOpenExternalLinks(true);
-    about->setTextInteractionFlags(Qt::TextBrowserInteraction);
-    about->setTextFormat(Qt::RichText);
-
-    QPushButton *conf = new QPushButton(i18n("&Configure Lokalize"), welcomeWidget);
-    QPushButton *openProject = new QPushButton(i18nc("@action:inmenu", "Open project"), welcomeWidget);
-    QPushButton *createProject = new QPushButton(i18nc("@action:inmenu", "Translate software"), welcomeWidget);
-    QPushButton *createOdfProject = new QPushButton(i18nc("@action:inmenu", "Translate OpenDocument"), welcomeWidget);
-    connect(conf, &QPushButton::clicked, SettingsController::instance(), &SettingsController::showSettingsDialog);
-    connect(openProject, &QPushButton::clicked, this, qOverload<>(&ProjectTab::projectOpenRequested));
-    connect(createProject, &QPushButton::clicked, SettingsController::instance(), &SettingsController::projectCreate);
-    connect(createOdfProject, &QPushButton::clicked, Project::instance(), &Project::projectOdfCreate);
-    QHBoxLayout *wbtnl = new QHBoxLayout();
-    wbtnl->addStretch(1);
-    wbtnl->addWidget(conf);
-    wbtnl->addWidget(openProject);
-    wbtnl->addWidget(createProject);
-    wbtnl->addWidget(createOdfProject);
-    wbtnl->addStretch(1);
-
-    wl->addStretch(1);
-    wl->addWidget(about);
-    wl->addStretch(1);
-    wl->addLayout(wbtnl);
-    wl->addStretch(1);
-
-    // END setup welcome widget
-    QWidget *baseWidget = new QWidget(this);
-    m_stackedLayout = new QStackedLayout(baseWidget);
+    m_tabLabel = i18nc("@title:tab", "Project Overview");
+    m_tabIcon = QIcon::fromTheme(QStringLiteral("project-open"));
     QWidget *w = new QWidget(this);
-    m_stackedLayout->addWidget(welcomeWidget);
-    m_stackedLayout->addWidget(w);
-    connect(Project::instance(), &Project::loaded, this, &ProjectTab::showRealProjectOverview);
-    if (Project::instance()->isLoaded()) // for --project cmd option
-        showRealProjectOverview();
-
     QVBoxLayout *l = new QVBoxLayout(w);
 
     m_filterEdit->setClearButtonEnabled(true);
@@ -122,8 +66,8 @@ ProjectTab::ProjectTab(QWidget *parent)
     connect(Project::instance()->model(), &ProjectModel::totalsChanged, this, &ProjectTab::updateStatusBar);
     connect(Project::instance()->model(), &ProjectModel::loadingAboutToStart, this, &ProjectTab::initStatusBarProgress);
 
-    setCentralWidget(baseWidget);
-    QStatusBar *statusBar = static_cast<LokalizeSubwindowBase2 *>(parent)->statusBar();
+    setCentralWidget(w);
+    QStatusBar *statusBar = static_cast<LokalizeTabPageBase *>(parent)->statusBar();
 
     m_progressBar = new QProgressBar(nullptr);
     m_progressBar->setVisible(false);
@@ -133,7 +77,6 @@ ProjectTab::ProjectTab(QWidget *parent)
 
     setXMLFile(QStringLiteral("projectmanagerui.rc"), true);
     setUpdatedXMLFile();
-    // QAction* action = KStandardAction::find(Project::instance(),&ProjectTab::showTM,actionCollection());
 
 #define ADD_ACTION_SHORTCUT_ICON(_name, _text, _shortcut, _icon)                                                                                               \
     action = nav->addAction(QStringLiteral(_name));                                                                                                            \
@@ -207,8 +150,6 @@ ProjectTab::ProjectTab(QWidget *parent)
     ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_T));
     connect(action, &QAction::triggered, this, &ProjectTab::toggleTranslatedFiles);
 
-    //    ADD_ACTION_SHORTCUT_ICON("edit_find",i18nc("@action:inmenu","Find in files"),Qt::AltModifier+Qt::Key_Down,"nextpo")
-    // connect(action, &QAction::triggered, this, &ProjectTab::gotoNextTransOnly);
     action = nav->addAction(KStandardAction::Find, this, SLOT(findTriggered()));
 
     KActionCategory *proj = new KActionCategory(i18nc("@title actions category", "Project"), ac);
@@ -222,15 +163,6 @@ ProjectTab::ProjectTab(QWidget *parent)
         statusBarItems.insert(i, QString());
 }
 
-void ProjectTab::showRealProjectOverview()
-{
-    m_stackedLayout->setCurrentIndex(1);
-}
-void ProjectTab::showWelcomeScreen()
-{
-    m_stackedLayout->setCurrentIndex(0);
-}
-
 void ProjectTab::toggleTranslatedFiles()
 {
     m_browser->toggleTranslatedFiles();
@@ -249,9 +181,7 @@ void ProjectTab::setFocus()
 
 void ProjectTab::setFilterRegExp()
 {
-    QRegularExpression newRegex(QRegularExpression::wildcardToRegularExpression(m_filterEdit->text(), QRegularExpression::UnanchoredWildcardConversion),
-                                QRegularExpression::InvertedGreedinessOption);
-    m_browser->proxyModel()->setFilterRegularExpression(newRegex);
+    m_browser->proxyModel()->setFilterRegularExpression(QRegularExpression(m_filterEdit->text()));
     if (m_filterEdit->text().size() > 2)
         m_browser->expandItems();
     else
@@ -270,12 +200,6 @@ void ProjectTab::contextMenuEvent(QContextMenuEvent *event)
         menu->addAction(i18nc("@action:inmenu", "Open"), this, &ProjectTab::openFile);
         menu->addSeparator();
     }
-    /*menu.addAction(i18nc("@action:inmenu","Find in files"),this,&ProjectTab::findInFiles);
-    menu.addAction(i18nc("@action:inmenu","Replace in files"),this,&ProjectTab::replaceInFiles);
-    menu.addAction(i18nc("@action:inmenu","Spellcheck files"),this,&ProjectTab::spellcheckFiles);
-    menu.addSeparator();
-    menu->addAction(i18nc("@action:inmenu","Get statistics for subfolders"),m_browser,&ProjectTab::expandItems);
-    */
     menu->addAction(i18nc("@action:inmenu", "Add to translation memory"), this, &ProjectTab::scanFilesToTM);
 
     menu->addAction(i18nc("@action:inmenu", "Search in files"), this, &ProjectTab::searchInFiles);
@@ -286,13 +210,6 @@ void ProjectTab::contextMenuEvent(QContextMenuEvent *event)
     if (QDir(Project::instance()->templatesRoot()).exists())
         menu->addAction(i18nc("@action:inmenu", "Search in files (including templates)"), this, &ProjectTab::searchInFilesInclTempl);
 
-    //     else if (Project::instance()->model()->hasChildren(/*m_proxyModel->mapToSource(*/(m_browser->currentIndex()))
-    //             )
-    //     {
-    //         menu.addSeparator();
-    //         menu.addAction(i18n("Force Scanning"),this,&ProjectTab::slotForceStats);
-    //
-    //     }
     menu->popup(event->globalPos());
 }
 
@@ -541,6 +458,4 @@ void ProjectTab::setLegacyUnitsCount(int to)
     initStatusBarProgress();
 }
 
-// bool ProjectTab::isShown() const {return isVisible();}
-
 #include "moc_projecttab.cpp"
