@@ -12,11 +12,10 @@
 #ifndef PROJECTTAB_H
 #define PROJECTTAB_H
 
-#include "lokalizesubwindowbase.h"
+#include "lokalizetabpagebase.h"
 
 #include <KMainWindow>
 #include <KProcess>
-
 #include <KXMLGUIClient>
 
 class QStackedLayout;
@@ -28,7 +27,7 @@ class QProgressBar;
 /**
  * Project Overview Tab
  */
-class ProjectTab : public LokalizeSubwindowBase2
+class ProjectTab : public LokalizeTabPageBase
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.ProjectOverview")
@@ -59,7 +58,6 @@ public:
     void setLegacyUnitsCount(int to);
 
 Q_SIGNALS:
-    void projectOpenRequested(QString path);
     void projectOpenRequested();
 
     void fileOpenRequested(const QString &, const bool setAsActive);
@@ -74,10 +72,6 @@ public Q_SLOTS:
     ///@returns list of selected files recursively
     Q_SCRIPTABLE QStringList selectedItems() const;
     Q_SCRIPTABLE bool currentItemIsTranslationFile() const;
-    void showRealProjectOverview();
-    void showWelcomeScreen();
-
-    // Q_SCRIPTABLE bool isShown() const;
 
 private Q_SLOTS:
     /**
@@ -126,8 +120,6 @@ private:
     QLineEdit *m_filterEdit{};
     QProgressBar *m_progressBar{};
 
-    QStackedLayout *m_stackedLayout{};
-
     KProcess *m_pologyProcess{};
     bool m_pologyProcessInProgress{};
 
