@@ -10,7 +10,7 @@
 #ifndef TMTAB_H
 #define TMTAB_H
 
-#include "lokalizesubwindowbase.h"
+#include "lokalizetabpagebase.h"
 #include "pos.h"
 
 #include <kmainwindow.h>
@@ -38,7 +38,7 @@ class ExecQueryJob;
 /**
  * Translation Memory tab
  */
-class TMTab : public LokalizeSubwindowBase2
+class TMTab : public LokalizeTabPageBase
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.TranslationMemory")
@@ -71,7 +71,6 @@ public Q_SLOTS:
     }
     Q_SCRIPTABLE bool findGuiTextPackage(QString text, QString package);
     Q_SCRIPTABLE void lookup(QString source, QString target);
-    // void lookup(DocPosition::Part, QString text);
 
 public Q_SLOTS:
     void performQuery();
@@ -127,7 +126,6 @@ public:
     enum Roles {
         FullPathRole = Qt::UserRole,
         TransStateRole = Qt::UserRole + 1,
-        // HtmlDisplayRole=FastSizeHintItemDelegate::HtmlDisplayRole
     };
 
     explicit TMDBModel(QObject *parent);
@@ -170,9 +168,6 @@ private:
 public:
     mutable QMutex m_dbOperationMutex;
 };
-
-// const QString& sourceRefine, const QString& targetRefine
-
 }
 
 #endif
